#include <algorithm>
#include <cmath>
#include <ext/alloc_traits.h>
#include <iostream>
#include <memory>
#include <utility>
#include <vector>

using namespace std;

vector<vector<pair<int, int>>>
computeNbServingsPossible(int N, int P, const vector<float> &R,
                          const vector<vector<float>> &Q) {
  vector<vector<pair<int, int>>> res(N, vector<pair<int, int>>(P));
  for (int i = 0; i < N; i++) {
    for (int j = 0; j < P; j++) {
      int nbMin = int(ceil(Q[i][j] / (1.1f * R[i])));
      int nbMax = int(trunc(Q[i][j] / (0.9f * R[i])));
      res[i][j] = make_pair(nbMin, nbMax);
    }
  }
  return res;
}

int solve(int N, int P, vector<vector<pair<int, int>>> nbServingsPossible) {
  for (int i = 0; i < N; i++)
    sort(nbServingsPossible.begin(), nbServingsPossible.end());

  int nbKits = 0;
  while (true) {
    bool stop = false;
    for (int i = 0; i < N; i++)
      if (nbServingsPossible[i].size() == 0) {
        stop = true;
        break;
      }
    if (stop)
      break;

    int consideredIngredient = 0;
    int consideredPack = 0;
    pair<int, int> minInterval = nbServingsPossible[0][0];
    for (int i = 0; i < N; i++) {
      for (int j = 0; j < nbServingsPossible[i].size(); j++) {
        if (nbServingsPossible[i][j] < minInterval) {
          consideredIngredient = i;
          consideredPack = j;
          minInterval = nbServingsPossible[i][j];
        }
      }
    }

    bool increasedNbKits = false;
    for (int nbServs =
             nbServingsPossible[consideredIngredient][consideredPack].first;
         nbServs <=
         nbServingsPossible[consideredIngredient][consideredPack].second;
         nbServs++) {
      bool allIngredientsFound = true;
      vector<int> used(N, -1);
      used[consideredIngredient] = consideredPack;
      for (int i = 0; i < N; i++) {
        if (i == consideredIngredient)
          continue;

        bool ingredientOk = false;
        for (int j2 = 0; j2 < nbServingsPossible[i].size(); j2++) {
          if (nbServs >= nbServingsPossible[i][j2].first &&
              nbServs <= nbServingsPossible[i][j2].second) {
            ingredientOk = true;
            used[i] = j2;
            break;
          }
        }
        if (!ingredientOk) {
          allIngredientsFound = false;
          break;
        }
      }
      if (allIngredientsFound) {
        nbKits++;
        for (int i = 0; i < N; i++)
          nbServingsPossible[i].erase(nbServingsPossible[i].begin() + used[i]);
        increasedNbKits = true;
        break;
      }
    }
    if (!increasedNbKits) {
      nbServingsPossible[consideredIngredient].erase(
          nbServingsPossible[consideredIngredient].begin() + consideredPack);
    }
  }
  return nbKits;
}

int main() {
  ios::sync_with_stdio(false);

  int T;
  cin >> T;
  for (int t = 0; t < T; t++) {
    int N, P;
    cin >> N >> P;

    vector<float> R(N);
    for (int i = 0; i < N; i++)
      cin >> R[i];

    vector<vector<float>> Q(N, vector<float>(P));
    for (int i = 0; i < N; i++) {
      for (int j = 0; j < P; j++) {
        cin >> Q[i][j];
      }
    }

    vector<vector<pair<int, int>>> nbServingsPossible =
        computeNbServingsPossible(N, P, R, Q);

    int nbKits = solve(N, P, nbServingsPossible);
    cout << "Case #" << t + 1 << ": " << nbKits << endl;
  }

  return 0;
}
